Module noiser

Module noiser 

Traits

Noiser
This trait lets you implement a custom noising function to add ε-differential privacy to a struct that implements Anonymizable DiffPriv already supports Laplace noise as a possible noiser