Noiser

Trait Noiser 

pub trait Noiser:
    Default
    + Clone
    + Sync {
    // Required method
    fn add_noise<M: Anonymizable>(
        &mut self,
        value: &M,
    ) -> Vec<QuasiIdentifierTypes>;
}
This trait lets you implement a custom noising function to add ε-differential privacy to a struct that implements Anonymizable DiffPriv already supports Laplace noise as a possible noiser

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors