Publisher

Trait Publisher 

pub trait Publisher {
    // Required method
    fn publish<M: Anonymizable>(&mut self, value: M, uuid: Uuid, dr: f64);
}
Generic trait for publishing the anonymized data Anonymizable also contains Serialize to make it easy to convert a value for specific publishers

Required Methods

fn publish<M: Anonymizable>(&mut self, value: M, uuid: Uuid, dr: f64)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors