pub struct Adult { /* private fields */ }Trait Implementations
Sourceimpl Anonymizable for Adult
impl Anonymizable for Adult
Sourcefn quasi_identifiers(&self) -> Vec<QuasiIdentifierTypes>
fn quasi_identifiers(&self) -> Vec<QuasiIdentifierTypes>
return the values of the quasi identifiers in the data struct
Sourcefn update_quasi_identifiers(&self, qi: Vec<QuasiIdentifierTypes>) -> Self
fn update_quasi_identifiers(&self, qi: Vec<QuasiIdentifierTypes>) -> Self
return a copy of the Anonymizable struct and replace its
quasi identifier attributes with given QI’s
we return a copy because we want to keep the original intact for new aggregation
Sourcefn sensitive_value(&self) -> SensitiveAttribute
fn sensitive_value(&self) -> SensitiveAttribute
return a copy of the sensitive attribute of the struct
Sourcefn extract_string_values(&self, uuid: Uuid, dr: f64) -> Vec<String>
fn extract_string_values(&self, uuid: Uuid, dr: f64) -> Vec<String>
extract all the values in string format to be used for creating CSV
fn get_timestamp(&self) -> SystemTime
Sourcefn calculate_difference(&self, other: &Self) -> f64
fn calculate_difference(&self, other: &Self) -> f64
compare 2 data points and return the euclidean difference between them
Sourcefn calculate_info_loss(&self, other: &Self) -> f64
fn calculate_info_loss(&self, other: &Self) -> f64
calculate the info loss between 2 different Anonymizable
structs
Sourcefn calculate_ordinal_distance(
ordinal_x: OrdinalType,
ordinal_y: OrdinalType,
) -> f64
fn calculate_ordinal_distance( ordinal_x: OrdinalType, ordinal_y: OrdinalType, ) -> f64
calculate the euclidean distance between 2 ordinal data category types
TODO: clarify that ranking starts at 1
Sourcefn calculate_interval_distance(
interval_x: IntervalType,
interval_y: IntervalType,
) -> f64
fn calculate_interval_distance( interval_x: IntervalType, interval_y: IntervalType, ) -> f64
calculate the euclidean distance between 2 interval data types
Sourcefn calculate_nominal_distance(
nominal_x: NominalType,
nominal_y: NominalType,
) -> f64
fn calculate_nominal_distance( nominal_x: NominalType, nominal_y: NominalType, ) -> f64
calculate the euclidean distance between 2 nominal data types
Sourceimpl<'de> Deserialize<'de> for Adult
impl<'de> Deserialize<'de> for Adult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more